Name:		dpm-dsi
Summary:	Disk Pool Manager (DPM) plugin for the Globus GridFTP server
Version:	1.9.7
Release:	6%{?dist}
License:	ASL 2.0
Group:		Applications/Internet
URL:		https://svnweb.cern.ch/trac/lcgdm/wiki/Dpm
# The source of this package was pulled from upstream's vcs. Use the
# following commands to generate the tarball:
# svn export http://svn.cern.ch/guest/lcgdm/dpm-dsi/tags/dpm-dsi_1_9_7b dpm-dsi-1.9.7
# tar -czvf dpm-dsi-1.9.7.tar.gz dpm-dsi-1.9.7
Source0:	%{name}-%{version}.tar.gz
Patch0:		%{name}-64.patch
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:		cmake
BuildRequires:		dmlite-devel
BuildRequires:		globus-gridftp-server-devel
BuildRequires:          globus-common-progs
BuildRequires:		voms-devel
BuildRequires:		yum-utils

Requires(preun):	chkconfig
Requires(preun):	initscripts
Requires(post):		chkconfig
Requires(postun):	initscripts
Requires:		dmlite-libs >= 0.7.1

%define _gridftp_server_version %(pkg-config --modversion globus-gridftp-server)
%if "%{_gridftp_server_version}" != ""
Requires:               globus-gridftp-server-progs%{?_isa} = %{_gridftp_server_version}
%else
Requires:               globus-gridftp-server-progs%{?_isa}
%endif

Provides:		DPM-gridftp-server = %{version}-%{release} 
Obsoletes:		DPM-gridftp-server <= 1.8.1
Provides:		DPM-DSI = %{version}-%{release} 
Obsoletes:		DPM-DSI <= 1.8.1

%description
The dpm-dsi package provides a Disk Pool Manager (DPM) plugin for the 
Globus GridFTP server, following the Globus Data Storage Interface (DSI).

The Disk Pool Manager (DPM) is a lightweight storage solution for grid sites.
It offers a simple way to create a disk-based grid storage element and 
supports relevant protocols (SRM, gridFTP, RFIO) for file 
management and access.

Globus provides open source grid software, including a server implementation
of the GridFTP protocol. This plugin implements the DPM backend specifics 
required to expose the data using this protocol.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p0

%build
%cmake . -DCMAKE_INSTALL_PREFIX=/

make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} install

install -p -d -m 755 %{buildroot}%{_localstatedir}/log/dpm-gsiftp

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%{_initrddir}/dpm-gsiftp
%config(noreplace) %{_sysconfdir}/logrotate.d/dpm-gsiftp
%config(noreplace) %{_sysconfdir}/sysconfig/dpm-gsiftp
%{_libdir}/libglobus_gridftp_server_dmlite*.so*
%{_localstatedir}/log/dpm-gsiftp
%doc LICENSE RELEASE-NOTES

%post
/sbin/chkconfig --add dpm-gsiftp
/sbin/ldconfig

%preun
if [ $1 -eq 0 ] ; then
	/sbin/service dpm-dsi stop > /dev/null 2>&1
	/sbin/chkconfig --del dpm-gsiftp
fi

%postun
/sbin/ldconfig 
if [ $1 -ge 1 ]; then
	/sbin/service dpm-gsiftp condrestart > /dev/null 2>&1 || :
fi

%changelog
* Thu May 19 2016 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.9.7-6
- Rebuilt for globus-gridftp-server 10.4

* Fri May 06 2016 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.9.7-5
- Rebuilt for globus-gridftp-server 10.2

* Mon May 02 2016 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.9.7-4
- Rebuilt for globus-gridftp-server 9.9

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.9.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jan 13 2016 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.9.7-2
- Rebuilt for globus-gridftp-server 9.4

* Thu Jan 07 2016 Andrey Kiryanov <andrey.Kiryanov.@cern.ch> - 1.9.7-1
- fix for Gridftp Redirection: transfers with checksums fail when delayed passive is enabled
- fix for Gridftp Redirection: transfer overwrite  fails
- fix for Gridftp logs not compressed
- Implemented checksum calculation on the disknodes with Gridftp Redirection enabled

* Thu Nov 26 2015 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.9.5-13
- Rebuilt for globus-gridftp-server 9.3

* Fri Nov 06 2015 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.9.5-12
- Rebuilt for globus-gridftp-server 9.1

* Tue Nov 03 2015 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.9.5-11
- Adapt properly to globus-gridftp-server 9.0

* Tue Oct 27 2015 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.9.5-10
- Rebuilt for globus-gridftp-server 9.0

* Sun Oct 25 2015 Mattias Ellert <mattias.ellert@fysast.uu.se> - 1.9.5-9
- Rebuilt for globus-gridftp-server 8.9

* Mon Aug 31 2015 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 1.9.5-8
- Rebuilt for globus-gridftp-server 8.7

* Tue Aug 11 2015 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 1.9.5-7
- Rebuilt for globus-gridftp-server 8.1

* Tue Jul 28 2015 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 1.9.5-6
- Rebuilt for globus-gridftp-server 8.0

* Tue Jun 23 2015 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 1.9.5-5
- Avoid hardcoded dependency on Globus

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue May 05 2015 Laurence Field <laurence.field@cern.ch> - 1.9.5-3
- Strict dependency towards Globus and minor fixes for compatibility

* Fri Apr 17 2015 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 1.9.5-2
- Missing fix by upstream

* Thu Apr 16 2015 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 1.9.5-1
- Update for new upstream release

* Wed Apr 08 2015 Alejandro Alvarez Ayllon <aalvarez@cern.ch> - 1.9.4-1
- Update for new upstream release

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Michal Simon <michal.simon@cern.ch> - 1.9.3-3
- Patch for the FTS2 issue 

* Thu May 15 2014 Alejandro Alvarez <aalvarez@cern.ch> - 1.9.3-2
- Patch for proper EOF handling

* Wed Mar 12 2014 Alejandro Alvarez <aalvarez@cern.ch> - 1.9.3-1
- Update for new upstream release
- Fixed bogus date

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon May 06 2013 Alejandro Alvarez <aalvarez@cern.ch> - 1.9.0-3
- Removed devel package
- Removed %{?_isa} suffix from globus-gridftp-server-progs

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Dec 19 2012 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.9.0-1
- Update for new upstream release

* Fri Dec 14 2012 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.3-1
- Update to new upstream release
- Removed previously required patches (integrated upstream)

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Nov 28 2011 Dan Horák <dan[at]danny.cz> - 1.8.2-6
- fix build on 64-bit arches (s390x, sparc64 and possibly others)

* Tue Nov 15 2011 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.2-5
- Removed architecture from globus-gridftp-server-progs requires

* Wed Nov 09 2011 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.2-4
- Added patch for proper libdir usage in ppc64

* Wed Nov 09 2011 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.2-3
- Added patch for LD_LIBRARY_PATH setting in init script

* Fri Nov 04 2011 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.2-2
- Removed README and LICENSE from devel package
- Added parallel flags to make command

* Mon Oct 17 2011 Ricardo Rocha <ricardo.rocha@cern.ch> - 1.8.2-1
- Initial build
